//
//  TCGBWebConfiguration.h
//  TCGBWebKit
//
//  Created by Park Panki on 2016. 12. 20..
//  Copyright © 2016년 NHN Entertainment. All rights reserved.
//

#import <UIKit/UIKit.h>

/** These constants indicate the type of launch style such as popup, fullscreen.
 * @see launchStyle
 */
typedef NS_ENUM(NSUInteger, TCGBWebViewLaunchStyle) {
    /** PopUp Style.
     * The background opacity can be set by `opacityBackground` property.<br/>
     * The background color can be set by `maskViewColor` property.<br/>
     * The close button can be set by `closeImagePathForPopup` property.<br/>
     * @see opacityBackground
     * @see maskViewColor
     */
    TCGBWebViewLaunchPopUp                       = 0,
    
    /** Full Screen Style.
     * There is not status bar.<br/>
     * The navigation bar height can be set by `navBarHeight` property.<br/>
     * The navigation bar title can be set by `webViewTitle` property.<br/>
     * The navigation bar color can be set by `navBarColor` property.<br/>
     * @see navBarHeight
     * @see webViewTitle
     * @see navBarColor
     */
    TCGBWebViewLaunchFullScreen                  = 1,
    
    /** Full Screen Style with status bar.
     * In this style, there is a status bar.
     * The navigation bar height can be set by `navBarHeight` property.<br/>
     * The navigation bar title can be set by `webViewTitle` property.<br/>
     * The navigation bar color can be set by `navBarColor` property.<br/>
     * @see navBarHeight
     * @see webViewTitle
     * @see navBarColor
     */
    TCGBWebViewLaunchFullScreenWithStatusBar     = 2,
    
    /** Full Screen Style with status bar.
     * In this style, there is not a status bar and navigation bar. It is just fullscreen.
     */
    TCGBWebViewLaunchFullScreenWithoutNavbar     = 3,
};

/** These constants indicate the type of orientation mask such as portrait all, landscape left and etc.
 * @see orientationMask
 */
typedef NS_ENUM(NSUInteger, TCGBWebViewOrientationMask) {
    /** Portrait.
     * Home Button on the bottom.
     * 0x000010, 2
     */
    TCGBWebViewOrientationMaskPortrait           = UIInterfaceOrientationMaskPortrait,
    
    /** Portrait UpsideDown.
     * Home Button on the top.
     * 0x000100, 4
     */
    TCGBWebViewOrientationMaskPortraitUpsideDown = UIInterfaceOrientationMaskPortraitUpsideDown,
    
    /** Portrait All.
     * Home Button on the top & bottom.
     * 0x000110, 6
     */
    TCGBWebViewOrientationMaskPortraitAll        = TCGBWebViewOrientationMaskPortrait | TCGBWebViewOrientationMaskPortraitUpsideDown,
    
    /** LandScape Left.
     * Home Button on the left.
     * 0x010000, 16
     */
    TCGBWebViewOrientationMaskLandScapeLeft      = UIInterfaceOrientationMaskLandscapeLeft,
    
    /** LandScape Right.
     * Home Button on the right.
     * 0x001000, 8
     */
    TCGBWebViewOrientationMaskLandScapeRight     = UIInterfaceOrientationMaskLandscapeRight,
    
    /** LandScape All.
     * Home Button on the left & right.
     * 0x011000, 24
     */
    TCGBWebViewOrientationMaskLandScapeAll       = TCGBWebViewOrientationMaskLandScapeLeft | TCGBWebViewOrientationMaskLandScapeRight,
    
    /** Mask All.
     * Home Button on the top & bottom & left & right.
     * 0x011110, 30
     */
    TCGBWebViewOrientationMaskAll                = UIInterfaceOrientationMaskAll,
    
    /** Mask All except Portrait UpsideDown.
     * Home Button on the bottom & left & right.
     * 0x011010, 26
     */
    TCGBWebViewOrientationMaskAllButUpsideDown   = UIInterfaceOrientationMaskAllButUpsideDown,
};

/// Deprecated. It will be deleted.
typedef NS_ENUM(NSUInteger, TCGBWebViewOrientationType) {
    TCGBWebViewOrientationPortrait               = (1 << UIInterfaceOrientationPortrait),
    TCGBWebViewOrientationLandScapeLeft          = (1 << UIInterfaceOrientationLandscapeLeft),
    TCGBWebViewOrientationLandScapeRight         = (1 << UIInterfaceOrientationLandscapeRight),
    TCGBWebViewOrientationPortraitUpsideDown     = (1 << UIInterfaceOrientationPortraitUpsideDown),
    TCGBWebViewOrientationLandScape              = (UIInterfaceOrientationMaskLandscapeLeft | UIInterfaceOrientationMaskLandscapeRight),
    TCGBWebViewOrientationAll                    = (UIInterfaceOrientationMaskPortrait | UIInterfaceOrientationMaskLandscapeLeft | UIInterfaceOrientationMaskLandscapeRight | UIInterfaceOrientationMaskPortraitUpsideDown),
    TCGBWebViewOrientationAllButUpsideDown       = (UIInterfaceOrientationMaskPortrait | UIInterfaceOrientationMaskLandscapeLeft | UIInterfaceOrientationMaskLandscapeRight),
};

/** The TCGBWebConfiguration configures the behavior of webview launching.
 */
@interface TCGBWebConfiguration : NSObject

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**
 OrientationMask.
 
 @warning Default is a UISupportedInterfaceOrientations value in the info.plist.
 */
@property (atomic) TCGBWebViewOrientationMask orientationMask;

/**
 Launching Style.
 
 @warning Default is a TCGBWebViewLaunchFullScreen.
 */
@property (atomic) TCGBWebViewLaunchStyle launchStyle;

/**
 Alpha value of the background.
 
 Only used in popup launch style.
 @warning This value should be between 0 and 1.
 */
@property (atomic, setter=setOpacityBackGround:) CGFloat opacityBackground;

/**
 Boolean value.
 
 @warning Default value is YES.
 */
@property (assign) BOOL isBackButtonVisible;

/**
 Navigation Bar Height.
 
 Only used in full screen launch style.
 @warning Default value is 50.
 */
@property (assign) CGFloat navBarHeight;

/**
 Mask View Color.
 
 Only used in popup launch style.
 @warning Default value is black.
 */
@property (strong, nonatomic) UIColor *maskViewColor;

/**
 Navigation Bar Color.
 
 Only used in full screen launch style.
 @warning Default value is blue.
 */
@property (strong, nonatomic) UIColor *navBarColor;

/**
 Navigation Bar Title.
 
 Only used in full screen launch style.
 @warning Default value is empty string.
 */
@property (strong, nonatomic) NSString *webViewTitle;

/**
 Close Image Path.
 
 Only used in popup launch style.
 @warning Default value is "TCGBwebkit-cancel-circle-white.png" in Gamebase.bundle
 */
@property (strong, nonatomic) NSString *closeImagePathForPopup;

/**
 Close Image Path.
 
 Only used in full screen launch style.
 @warning Default value is "TCGBwebkit-cancel-black.png" in Gamebase.bundle
 */
@property (strong, nonatomic) NSString *closeImagePathForFullScreenNavigation;

/**
 Back Button Image Path.
 
 Only used in full screen launch style.
 @warning Default value is "TCGBwebkit-goback-black.png" in Gamebase.bundle
 */
@property (strong, nonatomic) NSString *goBackImagePathForFullScreenNavigation;

/**
 Disabled Back Button Image Path.
 
 Only used in full screen launch style.
 @warning Default value is "TCGBwebkit-goback-gray.png" in Gamebase.bundle
 */
@property (strong, nonatomic) NSString *goBackDisabledImagePathForFullScreenNavigation;

/**
 UIViewController Delegate.
 
 It is used to delegate UIViewController's methods such as viewDidLoad: viewWillLoad: viewDidDisappear: and etc.
 */
@property (strong, nonatomic) UIViewController *delegate;

/// deprecated. will be deleted
@property (atomic) TCGBWebViewOrientationType orientationType;
@end
